Translate Toolkit 1.5.0
=======================

*Released on 25 November 2009*

Release notes for this release are still to be recovered, feel free to do some
way back searching and create a Pull Request for this release.
